@@ -6,6 +6,7 @@ These are classes designed to capture and handle various errors encountered when
 """
 import logging
 import warnings
+from typing import Type
 
 import requests.exceptions
 
@@ -98,55 +99,84 @@ class NotAuthenticatedAthlete(AuthError):
     """
     Exception when trying to access data which requires an authenticated athlete
     """
+
     pass
 
 
 # Warnings configuration and helper functions
-warnings.simplefilter('default')
+warnings.simplefilter("default")
 logging.captureWarnings(True)
 
 
-def warn_param_deprecation(param_name: str):
+def warn_method_deprecation(
+    klass: Type, method_name: str, alternative: str, alt_url: str = None
+):
+    alt_support_msg = (
+        f" See {alt_url} for more information." if alt_url else ""
+    )
+    warnings.warn(
+        f'The method "{method_name}" of class "{klass}" is deprecated and will be '
+        f'removed in the future. Instead, you can use "{alternative}".{alt_support_msg}',
+        DeprecationWarning,
+        stacklevel=3,
+    )
+
+
+def warn_param_unsupported(param_name: str):
     warnings.warn(
         f'The "{param_name}" parameter is unsupported by the Strava API. It has no '
-        'effect and may lead to errors in the future.',
+        "effect and may lead to errors in the future.",
         DeprecationWarning,
-        stacklevel=3
+        stacklevel=3,
+    )
+
+
+def warn_param_deprecation(
+    param_name: str, alternative: str, alt_url: str = None
+):
+    alt_support_msg = (
+        f" See {alt_url} for more information." if alt_url else ""
+    )
+    warnings.warn(
+        f'The "{param_name}" parameter is deprecated and will be removed'
+        f'in the future. Instead, you can use "{alternative}".{alt_support_msg}',
+        DeprecationWarning,
+        stacklevel=3,
     )
 
 
 def warn_param_unofficial(param_name: str):
     warnings.warn(
         f'The "{param_name}" parameter is undocumented in the Strava API. Its use '
-        'may lead to unexpected behavior or errors in the future.',
+        "may lead to unexpected behavior or errors in the future.",
         FutureWarning,
-        stacklevel=3
+        stacklevel=3,
     )
 
 
 def warn_attribute_unofficial(attr_name: str):
     warnings.warn(
         f'The "{attr_name}" parameter is undocumented in the Strava API. Its use '
-        'may lead to unexpected behavior or errors in the future.',
+        "may lead to unexpected behavior or errors in the future.",
         FutureWarning,
-        stacklevel=3
+        stacklevel=3,
     )
 
 
 def warn_method_unofficial(method_name: str):
     warnings.warn(
         f'The "{method_name}" method is undocumented in the Strava API. Its use '
-        'may lead to unexpected behavior or errors in the future.',
+        "may lead to unexpected behavior or errors in the future.",
         FutureWarning,
-        stacklevel=3
+        stacklevel=3,
     )
 
 
 def warn_units_deprecated():
     warnings.warn(
-        'You are using a Quantity object or attributes from the units library, which is '
-        'deprecated. Support for these types will be removed in the future. Instead, '
-        'please use Quantity objects from the Pint package (https://pint.readthedocs.io).',
+        "You are using a Quantity object or attributes from the units library, which is "
+        "deprecated. Support for these types will be removed in the future. Instead, "
+        "please use Quantity objects from the Pint package (https://pint.readthedocs.io).",
         DeprecationWarning,
-        stacklevel=3
+        stacklevel=3,
     )
