@@ -26,10 +26,21 @@ from stravalib import Client
 
 
 class StravaAuthHTTPServer(HTTPServer):
-
-    def __init__(self, server_address, RequestHandlerClass, client_id, client_secret, bind_and_activate=True):
-        HTTPServer.__init__(self, server_address, RequestHandlerClass, bind_and_activate=bind_and_activate)
-        self.logger = logging.getLogger('auth_server.http')
+    def __init__(
+        self,
+        server_address,
+        RequestHandlerClass,
+        client_id,
+        client_secret,
+        bind_and_activate=True,
+    ):
+        HTTPServer.__init__(
+            self,
+            server_address,
+            RequestHandlerClass,
+            bind_and_activate=bind_and_activate,
+        )
+        self.logger = logging.getLogger("auth_server.http")
         self.client_id = client_id
         self.client_secret = client_secret
         self.listening_event = threading.Event()
@@ -40,36 +51,44 @@ class StravaAuthHTTPServer(HTTPServer):
 
 
 class RequestHandler(BaseHTTPRequestHandler):
-
     def do_GET(self):
-
         request_path = self.path
 
         parsed_path = urlparse.urlparse(request_path)
 
         client = Client()
 
-        if request_path.startswith('/authorization'):
+        if request_path.startswith("/authorization"):
             self.send_response(200)
             self.send_header(b"Content-type", b"text/plain")
             self.end_headers()
 
             self.wfile.write(b"Authorization Handler\n\n")
-            code = urlparse.parse_qs(parsed_path.query).get('code')
+            code = urlparse.parse_qs(parsed_path.query).get("code")
             if code:
                 code = code[0]
-                token_response = client.exchange_code_for_token(client_id=self.server.client_id,
-                                                              client_secret=self.server.client_secret,
-                                                              code=code)
-                access_token = token_response['access_token']
-                self.server.logger.info("Exchanged code {} for access token {}".format(code, access_token))
+                token_response = client.exchange_code_for_token(
+                    client_id=self.server.client_id,
+                    client_secret=self.server.client_secret,
+                    code=code,
+                )
+                access_token = token_response["access_token"]
+                self.server.logger.info(
+                    "Exchanged code {} for access token {}".format(
+                        code, access_token
+                    )
+                )
                 self.wfile.write(b"Access Token: {}\n".format(access_token))
             else:
                 self.server.logger.error("No code param received.")
                 self.wfile.write(b"ERROR: No code param recevied.\n")
         else:
-            url = client.authorization_url(client_id=self.server.client_id,
-                                           redirect_uri='http://localhost:{}/authorization'.format(self.server.server_port))
+            url = client.authorization_url(
+                client_id=self.server.client_id,
+                redirect_uri="http://localhost:{}/authorization".format(
+                    self.server.server_port
+                ),
+            )
 
             self.send_response(302)
             self.send_header("Content-type", "text/plain")
@@ -79,27 +98,52 @@ class RequestHandler(BaseHTTPRequestHandler):
 
 
 def main(port, client_id, client_secret):
+    logging.basicConfig(
+        level=logging.INFO, format="%(levelname)-8s %(message)s"
+    )
 
-    logging.basicConfig(level=logging.INFO, format='%(levelname)-8s %(message)s')
+    logger = logging.getLogger("auth_responder")
+    logger.info("Listening on localhost:%s" % port)
 
-    logger = logging.getLogger('auth_responder')
-    logger.info('Listening on localhost:%s' % port)
-
-    server = StravaAuthHTTPServer(('', port), RequestHandler, client_id=client_id, client_secret=client_secret)
+    server = StravaAuthHTTPServer(
+        ("", port),
+        RequestHandler,
+        client_id=client_id,
+        client_secret=client_secret,
+    )
     server.serve_forever()
 
 
 if __name__ == "__main__":
+    parser = argparse.ArgumentParser(
+        description="Run a local web server to receive authorization responses from Strava."
+    )
 
-    parser = argparse.ArgumentParser(description="Run a local web server to receive authorization responses from Strava.")
+    parser.add_argument(
+        "-p",
+        "--port",
+        help="Which port to bind to",
+        action="store",
+        type=int,
+        default=8000,
+    )
 
-    parser.add_argument('-p', '--port', help='Which port to bind to',
-                        action='store', type=int, default=8000)
-
-    parser.add_argument('--client-id', help='Strava API Client ID',
-                        action='store', required=True)
-    parser.add_argument('--client-secret', help='Strava API Client Secret',
-                        action='store', required=True)
+    parser.add_argument(
+        "--client-id",
+        help="Strava API Client ID",
+        action="store",
+        required=True,
+    )
+    parser.add_argument(
+        "--client-secret",
+        help="Strava API Client Secret",
+        action="store",
+        required=True,
+    )
     args = parser.parse_args()
 
-    main(port=args.port, client_id=args.client_id, client_secret=args.client_secret)
+    main(
+        port=args.port,
+        client_id=args.client_id,
+        client_secret=args.client_secret,
+    )
