@@ -15,38 +15,46 @@ class UnitsLikeQuantity(UnitsQuantity):
 
 
 @pytest.mark.parametrize(
-    'from_unit,to_unit,expected_magnitude,expected_unit',
+    "from_unit,to_unit,expected_magnitude,expected_unit",
     (
-        (None, 'meter', 1, 'meter'),
-        ('meter', 'meter', 1, 'meter'),
-        ('km', 'meter', 1000, 'meter'),
-        ('m/s', 'kph', 3.6, 'kilometer / hour')
-    )
+        (None, "meter", 1, "meter"),
+        ("meter", "meter", 1, "meter"),
+        ("km", "meter", 1000, "meter"),
+        ("m/s", "kph", 3.6, "kilometer / hour"),
+    ),
 )
 class TestUnitConversion:
-    def test_conversion_legacy(self, from_unit, to_unit, expected_magnitude, expected_unit):
+    def test_conversion_legacy(
+        self, from_unit, to_unit, expected_magnitude, expected_unit
+    ):
         quantity = UnitsLikeQuantity(1, from_unit) if from_unit else 1
         with pytest.warns(DeprecationWarning):
             converted_quantity = getattr(uh, to_unit)(quantity)
-            assert converted_quantity.num == pytest.approx(expected_magnitude, .01)
+            assert converted_quantity.num == pytest.approx(
+                expected_magnitude, 0.01
+            )
             assert str(converted_quantity.unit) == expected_unit
 
-    def test_conversion(self, from_unit, to_unit, expected_magnitude, expected_unit):
+    def test_conversion(
+        self, from_unit, to_unit, expected_magnitude, expected_unit
+    ):
         quantity = 1 * Unit(from_unit) if from_unit else 1
         converted_quantity = getattr(uh, to_unit)(quantity)
-        assert converted_quantity.magnitude == pytest.approx(expected_magnitude, .01)
+        assert converted_quantity.magnitude == pytest.approx(
+            expected_magnitude, 0.01
+        )
         assert str(converted_quantity.units) == expected_unit
 
 
 @pytest.mark.parametrize(
-    'obj,expected_result,expected_warning',
+    "obj,expected_result,expected_warning",
     (
-        (pint.Quantity('m'), True, None),
-        (uh.Quantity(pint.Quantity('m')), True, None),
+        (pint.Quantity("m"), True, None),
+        (uh.Quantity(pint.Quantity("m")), True, None),
         (uh.meters(1), True, None),
-        (UnitsLikeQuantity(1, 'meter'), True, DeprecationWarning),
-        (42, False, None)
-    )
+        (UnitsLikeQuantity(1, "meter"), True, DeprecationWarning),
+        (42, False, None),
+    ),
 )
 def test_is_quantity_type(obj, expected_result, expected_warning):
     if expected_warning:
@@ -58,7 +66,8 @@ def test_is_quantity_type(obj, expected_result, expected_warning):
 
 def test_legacy_accessors():
     assert uh.meters(10).num == 10
-    assert uh.meters(10).unit == 'meter'
+    assert uh.meters(10).unit == "meter"
+
 
 def test_arithmetic_comparison_support():
     assert int(uh.meters(2.1)) == 2
