@@ -33,10 +33,14 @@ def total_seconds(td):
     total_seconds() only available since Python 2.7
     https://docs.python.org/2/library/datetime.html#datetime.timedelta.total_seconds
     """
-    return (td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) / 10**6
+    return (
+        td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6
+    ) / 10**6
 
 
-RequestRate = collections.namedtuple('RequestRate', ['short_usage', 'long_usage', 'short_limit', 'long_limit'])
+RequestRate = collections.namedtuple(
+    "RequestRate", ["short_usage", "long_usage", "short_limit", "long_limit"]
+)
 
 
 def get_rates_from_response_headers(headers):
@@ -48,11 +52,15 @@ def get_rates_from_response_headers(headers):
     :rtype: Optional[RequestRate]
     """
     try:
-        usage_rates = [int(v) for v in headers['X-RateLimit-Usage'].split(',')]
-        limit_rates = [int(v) for v in headers['X-RateLimit-Limit'].split(',')]
+        usage_rates = [int(v) for v in headers["X-RateLimit-Usage"].split(",")]
+        limit_rates = [int(v) for v in headers["X-RateLimit-Limit"].split(",")]
 
-        return RequestRate(short_usage=usage_rates[0], long_usage=usage_rates[1],
-                           short_limit=limit_rates[0], long_limit=limit_rates[1])
+        return RequestRate(
+            short_usage=usage_rates[0],
+            long_usage=usage_rates[1],
+            short_limit=limit_rates[0],
+            long_limit=limit_rates[1],
+        )
     except KeyError:
         return None
 
@@ -66,7 +74,15 @@ def get_seconds_until_next_quarter(now=None):
     """
     if now is None:
         now = arrow.utcnow()
-    return 899 - (now - now.replace(minute=(now.minute // 15) * 15, second=0, microsecond=0)).seconds
+    return (
+        899
+        - (
+            now
+            - now.replace(
+                minute=(now.minute // 15) * 15, second=0, microsecond=0
+            )
+        ).seconds
+    )
 
 
 def get_seconds_until_next_day(now=None):
@@ -78,11 +94,10 @@ def get_seconds_until_next_day(now=None):
     """
     if now is None:
         now = arrow.utcnow()
-    return (now.ceil('day') - now).seconds
+    return (now.ceil("day") - now).seconds
 
 
 class XRateLimitRule(object):
-
     def __init__(self, limits, force_limits=False):
         """
 
@@ -90,7 +105,9 @@ class XRateLimitRule(object):
         :param force_limits: If False (default), this rule will set/update its limits based on what the Strava API
         tells it. If True, the provided limits will be enforced, i.e. ignoring the limits given by the API.
         """
-        self.log = logging.getLogger('{0.__module__}.{0.__name__}'.format(self.__class__))
+        self.log = logging.getLogger(
+            "{0.__module__}.{0.__name__}".format(self.__class__)
+        )
         self.rate_limits = limits
         # should limit args be validated?
         self.limit_time_invalid = 0
@@ -111,39 +128,54 @@ class XRateLimitRule(object):
         rates = get_rates_from_response_headers(response_headers)
 
         if rates:
-            self.log.debug("Updating rate-limit limits and usage from headers: {}".format(rates))
-            self.rate_limits['short']['usage'] = rates.short_usage
-            self.rate_limits['long']['usage'] = rates.long_usage
+            self.log.debug(
+                "Updating rate-limit limits and usage from headers: {}".format(
+                    rates
+                )
+            )
+            self.rate_limits["short"]["usage"] = rates.short_usage
+            self.rate_limits["long"]["usage"] = rates.long_usage
 
             if not self.force_limits:
-                self.rate_limits['short']['limit'] = rates.short_limit
-                self.rate_limits['long']['limit'] = rates.long_limit
+                self.rate_limits["short"]["limit"] = rates.short_limit
+                self.rate_limits["long"]["limit"] = rates.long_limit
 
     def _check_limit_rates(self, limit):
-        if limit['usage'] >= limit['limit']:
-            self.log.debug("Rate limit of {0} reached.".format(limit['limit']))
-            limit['lastExceeded'] = datetime.now()
-            self._raise_rate_limit_exception(limit['limit'], limit['time'])
+        if limit["usage"] >= limit["limit"]:
+            self.log.debug("Rate limit of {0} reached.".format(limit["limit"]))
+            limit["lastExceeded"] = datetime.now()
+            self._raise_rate_limit_exception(limit["limit"], limit["time"])
 
     def _check_limit_time_invalid(self, limit):
         self.limit_time_invalid = 0
-        if limit['lastExceeded'] is not None:
-            delta = (datetime.now() - limit['lastExceeded']).total_seconds()
-            if delta < limit['time']:
-                self.limit_time_invalid = limit['time'] - delta
-                self.log.debug("Rate limit invalid duration {0} seconds."
-                               .format(self.limit_time_invalid))
-                self._raise_rate_limit_timeout(self.limit_timeout, limit['limit'])
+        if limit["lastExceeded"] is not None:
+            delta = (datetime.now() - limit["lastExceeded"]).total_seconds()
+            if delta < limit["time"]:
+                self.limit_time_invalid = limit["time"] - delta
+                self.log.debug(
+                    "Rate limit invalid duration {0} seconds.".format(
+                        self.limit_time_invalid
+                    )
+                )
+                self._raise_rate_limit_timeout(
+                    self.limit_timeout, limit["limit"]
+                )
 
     def _raise_rate_limit_exception(self, timeout, limit_rate):
-        raise exc.RateLimitExceeded("Rate limit of {0} exceeded. "
-                                    "Try again in {1} seconds.".format(limit_rate, timeout),
-                                    limit=limit_rate, timeout=timeout)
+        raise exc.RateLimitExceeded(
+            "Rate limit of {0} exceeded. "
+            "Try again in {1} seconds.".format(limit_rate, timeout),
+            limit=limit_rate,
+            timeout=timeout,
+        )
 
     def _raise_rate_limit_timeout(self, timeout, limit_rate):
-        raise exc.RateLimitTimeout("Rate limit of {0} exceeded. "
-                                   "Try again in {1} seconds.".format(limit_rate, timeout),
-                                   limit=limit_rate, timeout=timeout)
+        raise exc.RateLimitTimeout(
+            "Rate limit of {0} exceeded. "
+            "Try again in {1} seconds.".format(limit_rate, timeout),
+            limit=limit_rate,
+            timeout=timeout,
+        )
 
 
 class SleepingRateLimitRule(object):
@@ -153,7 +185,14 @@ class SleepingRateLimitRule(object):
     are reached within their period, this limiter will wait until the end of that period. It will NOT raise
     any kind of exception in this case.
     """
-    def __init__(self, priority='high', short_limit=10000, long_limit=1000000, force_limits=False):
+
+    def __init__(
+        self,
+        priority="high",
+        short_limit=10000,
+        long_limit=1000000,
+        force_limits=False,
+    ):
         """
         Constructs a new SleepingRateLimitRule.
         :param priority: The priority for this rule. When 'low', the cool-down period after each request will be such
@@ -167,50 +206,69 @@ class SleepingRateLimitRule(object):
         :param force_limits: If False (default), this rule will set/update its limits based on what the Strava API
         tells it. If True, the provided limits will be enforced, i.e. ignoring the limits given by the API.
         """
-        if priority not in ['low', 'medium', 'high']:
-            raise ValueError('Invalid priority "{0}", expecting one of "low", "medium" or "high"'.format(priority))
+        if priority not in ["low", "medium", "high"]:
+            raise ValueError(
+                'Invalid priority "{0}", expecting one of "low", "medium" or "high"'.format(
+                    priority
+                )
+            )
 
-        self.log = logging.getLogger('{0.__module__}.{0.__name__}'.format(self.__class__))
+        self.log = logging.getLogger(
+            "{0.__module__}.{0.__name__}".format(self.__class__)
+        )
         self.priority = priority
         self.short_limit = short_limit
         self.long_limit = long_limit
         self.force_limits = force_limits
 
-    def _get_wait_time(self, short_usage, long_usage, seconds_until_short_limit, seconds_until_long_limit):
+    def _get_wait_time(
+        self,
+        short_usage,
+        long_usage,
+        seconds_until_short_limit,
+        seconds_until_long_limit,
+    ):
         if long_usage >= self.long_limit:
-            self.log.warning('Long term API rate limit exceeded')
+            self.log.warning("Long term API rate limit exceeded")
             return seconds_until_long_limit
         elif short_usage >= self.short_limit:
-            self.log.warning('Short term API rate limit exceeded')
+            self.log.warning("Short term API rate limit exceeded")
             return seconds_until_short_limit
 
-        if self.priority == 'high':
+        if self.priority == "high":
             return 0
-        elif self.priority == 'medium':
+        elif self.priority == "medium":
             return seconds_until_short_limit / (self.short_limit - short_usage)
-        elif self.priority == 'low':
+        elif self.priority == "low":
             return seconds_until_long_limit / (self.long_limit - long_usage)
 
     def __call__(self, response_headers):
         rates = get_rates_from_response_headers(response_headers)
 
         if rates:
-            time.sleep(self._get_wait_time(rates.short_usage, rates.long_usage,
-                                           get_seconds_until_next_quarter(), get_seconds_until_next_day()))
+            time.sleep(
+                self._get_wait_time(
+                    rates.short_usage,
+                    rates.long_usage,
+                    get_seconds_until_next_quarter(),
+                    get_seconds_until_next_day(),
+                )
+            )
             if not self.force_limits:
                 self.short_limit = rates.short_limit
                 self.long_limit = rates.long_limit
 
 
 class RateLimitRule(object):
-
     def __init__(self, requests, seconds, raise_exc=False):
         """
         :param requests: Number of requests for limit.
         :param seconds: The number of seconds for that number of requests (may be float)
         :param raise_exc: Whether to raise an exception when limit is reached (as opposed to pausing)
         """
-        self.log = logging.getLogger('{0.__module__}.{0.__name__}'.format(self.__class__))
+        self.log = logging.getLogger(
+            "{0.__module__}.{0.__name__}".format(self.__class__)
+        )
         self.timeframe = timedelta(seconds=seconds)
         self.requests = requests
         self.tab = collections.deque(maxlen=self.requests)
@@ -228,22 +286,37 @@ class RateLimitRule(object):
         if len(self.tab) == self.requests:
             # Grab the oldest (leftmost) timestamp and check to see if it is greater than 1 second
             delta = datetime.now() - self.tab[0]
-            if delta < self.timeframe:  # Has it been less than configured timeframe since oldest request?
+            if (
+                delta < self.timeframe
+            ):  # Has it been less than configured timeframe since oldest request?
                 if self.raise_exc:
-                    raise exc.RateLimitExceeded("Rate limit exceeded (can try again in {0})".format(self.timeframe - delta))
+                    raise exc.RateLimitExceeded(
+                        "Rate limit exceeded (can try again in {0})".format(
+                            self.timeframe - delta
+                        )
+                    )
                 else:
                     # Wait the difference between timeframe and the oldest request.
                     td = self.timeframe - delta
-                    sleeptime = hasattr(td, 'total_seconds') and td.total_seconds() or total_seconds(td)
-                    self.log.debug("Rate limit triggered; sleeping for {0}".format(sleeptime))
+                    sleeptime = (
+                        hasattr(td, "total_seconds")
+                        and td.total_seconds()
+                        or total_seconds(td)
+                    )
+                    self.log.debug(
+                        "Rate limit triggered; sleeping for {0}".format(
+                            sleeptime
+                        )
+                    )
                     time.sleep(sleeptime)
         self.tab.append(datetime.now())
 
 
 class RateLimiter(object):
-
     def __init__(self):
-        self.log = logging.getLogger('{0.__module__}.{0.__name__}'.format(self.__class__))
+        self.log = logging.getLogger(
+            "{0.__module__}.{0.__name__}".format(self.__class__)
+        )
         self.rules = []
 
     def __call__(self, args):
@@ -276,15 +349,28 @@ class DefaultRateLimiter(RateLimiter):
 
         super(DefaultRateLimiter, self).__init__()
 
-        self.rules.append(XRateLimitRule(
-            {'short': {'usageFieldIndex': 0, 'usage': 0,
-                         # 60s * 15 = 15 min
-                         'limit': 600, 'time': (60*15),
-                         'lastExceeded': None},
-             'long': {'usageFieldIndex': 1, 'usage': 0,
+        self.rules.append(
+            XRateLimitRule(
+                {
+                    "short": {
+                        "usageFieldIndex": 0,
+                        "usage": 0,
+                        # 60s * 15 = 15 min
+                        "limit": 600,
+                        "time": (60 * 15),
+                        "lastExceeded": None,
+                    },
+                    "long": {
+                        "usageFieldIndex": 1,
+                        "usage": 0,
                         # 60s * 60m * 24 = 1 day
-                        'limit': 30000, 'time': (60*60*24),
-                        'lastExceeded': None}}))
+                        "limit": 30000,
+                        "time": (60 * 60 * 24),
+                        "lastExceeded": None,
+                    },
+                }
+            )
+        )
 
         # XRateLimitRule used instead of timer based RateLimitRule
         # self.rules.append(RateLimitRule(requests=40, seconds=60, raise_exc=False))
